Config class
For security reasons, environment variables should be used to configure sensitive settings. Configuration class for seckit package. Contains settings for JWT secrets, database encryption, and environment flags.
Constructors
Properties
- dbSecretKey → String
-
final
- devAuthToken → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isProd → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretKey → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited